@@ -3,6 +3,6 @@ from .eltnode import EltNode
 from .eltrpc import EltRpc
 from .eltinterface import EltInterface
 from .eltmanager import EltManager, open_elt_manager
-from .config import GROUP 
+from .config import GROUP, eltconfig 
 from .tools import default_node_map, default_interface_map
 from . import io
