@@ -2,7 +2,7 @@ from .motor import Motor
 from .shutter import Shutter
 from .time import Time
 from .adc import Adc
-from .ccs import CcsSim
+from .ccssim import CcsSim
 from .drot import Drot
 from .lamp import Lamp
 from .piezo import Piezo  
